@@ -9,12 +9,18 @@ def multisub(sub_dict, string):
     return sub(rgx, lambda m: sub_dict.get(m.group()), string)
 
 
-def strict_input(text, wrong_text=None, choices=None, regex=None, flush=False):
+def strict_input(
+    text, wrong_text=None, choices=None, regex=None, flush=False, check=None
+):
     """Get user input with some requirements"""
     inp = input(text)
     if flush:
         erase(len(findall(r"\n", text)) + 1)
-    while (choices and inp not in choices) and (regex and not match(regex, inp)):
+    while (
+        (not choices or choices and inp not in choices)
+        and (not regex or regex and not match(regex, inp))
+        and (not check or check and not check(inp))
+    ):
         if wrong_text:
             inp = input(wrong_text)
         else:
